==> mysql-workbench-community-6.0.8-nodocs-src.tar.gz: mysql-workbench-community-6.0.8-nodocs-src/backend/wbprivate/model/wb_template_list.h <==
/*
 * Copyright (c) 2013, Oracle and/or its affiliates. All rights reserved.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; version 2 of the
 * License.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301  USA
 */

#ifndef _TABLE_TEMPLATE_LIST_H_
#define _TABLE_TEMPLATE_LIST_H_

#include "snippet_list.h"
#include "mforms/box.h"
#include "grts/structs.workbench.physical.h"

namespace wb
{
  class WBContextModel;
};

namespace mforms
{
  class ToolBar;
  class ToolBarItem;
  class ScrollPanel;
};


class TableTemplatePanel;

class TableTemplateList : public BaseSnippetList, public bec::ListModel
{
  grt::GRT *_grt;
  TableTemplatePanel *_owner;

  void prepare_context_menu();
  void menu_will_show();

  virtual void mouse_double_click(int button, int x, int y);

  virtual int count();
  virtual bool get_field(const bec::NodeId &node, int column, std::string &value);
  virtual void refresh();
public:
  std::string get_selected_template();
  TableTemplateList(grt::GRT *grt, TableTemplatePanel *owner);
  ~TableTemplateList();
};


class TableTemplatePanel : public mforms::Box
{
  grt::GRT *_grt;
  TableTemplateList _templates;
  mforms::ToolBar *_toolbar;
  mforms::ScrollPanel *_scroll_panel;
  wb::WBContextModel *_context;

  void toolbar_item_activated(mforms::ToolBarItem *item);
public:
  TableTemplatePanel(grt::GRT *grt, wb::WBContextModel *cmodel);

  void on_action(const std::string& action);  
};

#endif

==> mysql-workbench-community-6.1.3-nodocs-src.tar.gz: mysql-workbench-community-6.1.3-nodocs-src/backend/wbprivate/model/wb_template_list.h <==
/*
 * Copyright (c) 2013, Oracle and/or its affiliates. All rights reserved.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; version 2 of the
 * License.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301  USA
 */

#ifndef _TABLE_TEMPLATE_LIST_H_
#define _TABLE_TEMPLATE_LIST_H_

#include "snippet_list.h"
#include "mforms/box.h"
#include "grts/structs.workbench.physical.h"

namespace wb
{
  class WBContextModel;
};

namespace mforms
{
  class ToolBar;
  class ToolBarItem;
  class ScrollPanel;
};


class TableTemplatePanel;

class TableTemplateList : public BaseSnippetList, public bec::ListModel
{
  grt::GRT *_grt;
  TableTemplatePanel *_owner;

  void prepare_context_menu();
  void menu_will_show();

  virtual bool mouse_double_click(mforms::MouseButton button, int x, int y);

  virtual int count();
  virtual bool get_field(const bec::NodeId &node, int column, std::string &value);
  virtual void refresh();
public:
  std::string get_selected_template();
  TableTemplateList(grt::GRT *grt, TableTemplatePanel *owner);
  ~TableTemplateList();
};


class TableTemplatePanel : public mforms::Box
{
  grt::GRT *_grt;
  TableTemplateList _templates;
  mforms::ToolBar *_toolbar;
  mforms::ScrollPanel *_scroll_panel;
  wb::WBContextModel *_context;

  void toolbar_item_activated(mforms::ToolBarItem *item);
public:
  TableTemplatePanel(grt::GRT *grt, wb::WBContextModel *cmodel);

  void on_action(const std::string& action);  
};

#endif
